"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

var _bootstrapOne = _interopRequireDefault(require("./bootstrap-one"));

var _shutdownOne = _interopRequireDefault(require("./shutdown-one"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _debugLevels.default)('resolve:runtime:bootstrap');

const bootstrap = async resolve => {
  log.debug('bootstrap started');
  const promises = [];
  const existingEventSubscribers = (await resolve.eventstoreAdapter.getEventSubscribers({
    applicationName: resolve.eventSubscriberScope
  })).map(({
    eventSubscriber
  }) => eventSubscriber);

  for (const {
    name,
    eventTypes
  } of resolve.eventListeners.values()) {
    promises.push((0, _bootstrapOne.default)({
      applicationName: resolve.eventSubscriberScope,
      eventstoreAdapter: resolve.eventstoreAdapter,
      eventSubscriber: resolve.eventSubscriber,
      name,
      eventTypes,
      destination: resolve.getEventSubscriberDestination(name),
      upstream: resolve.upstream,
      ensureQueue: resolve.ensureQueue
    }));
  }

  for (const name of existingEventSubscribers.filter(name => !resolve.eventListeners.has(name))) {
    promises.push((0, _shutdownOne.default)({
      applicationName: resolve.eventSubscriberScope,
      eventstoreAdapter: resolve.eventstoreAdapter,
      eventSubscriber: resolve.eventSubscriber,
      name,
      upstream: resolve.upstream,
      deleteQueue: resolve.deleteQueue,
      soft: true
    }));
  }

  await Promise.all(promises);
  log.debug('bootstrap successful');
  return 'ok';
};

var _default = bootstrap;
exports.default = _default;
//# sourceMappingURL=bootstrap.js.map