"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _index = _interopRequireDefault(require("../common/command/index"));

var _index2 = _interopRequireDefault(require("../common/query/index"));

var _index3 = _interopRequireDefault(require("../common/saga/index"));

var _crypto = _interopRequireDefault(require("crypto"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _liveEntryDir = _interopRequireDefault(require("./utils/live-entry-dir"));

var _notifyEventSubscribers = _interopRequireDefault(require("./notify-event-subscribers"));

var _onCommandExecuted = _interopRequireDefault(require("./on-command-executed"));

var _eventSubscriber = _interopRequireDefault(require("./event-subscriber"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_WORKER_LIFETIME = 4 * 60 * 1000;

const initResolve = async resolve => {
  var _domain$middlewares;

  const performanceTracer = resolve.performanceTracer;
  const {
    eventstoreAdapter: createEventstoreAdapter,
    readModelConnectors: readModelConnectorsCreators
  } = resolve.assemblies;
  const {
    invokeBuildAsync,
    eventSubscriberScope,
    uploader,
    scheduler,
    monitoring,
    domainInterop,
    domain
  } = resolve;
  const eventstoreAdapter = createEventstoreAdapter();
  const readModelConnectors = {};

  for (const name of Object.keys(readModelConnectorsCreators)) {
    readModelConnectors[name] = readModelConnectorsCreators[name]({
      performanceTracer,
      monitoring
    });
  }

  if (resolve.getVacantTimeInMillis == null) {
    const endTime = Date.now() + DEFAULT_WORKER_LIFETIME;

    resolve.getVacantTimeInMillis = () => endTime - Date.now();
  }

  const readModelSources = new Proxy({}, {
    get(target, key) {
      if (!target.hasOwnProperty(key)) {
        target[key] = null;
        const entryDir = (0, _liveEntryDir.default)();

        if (domain.readModels.find(({
          name
        }) => name === key) && entryDir != null) {
          try {
            target[key] = _fs.default.readFileSync(_path.default.join(entryDir, `read-model-${key}.js`)).toString('utf8');
          } catch (err) {}
        }
      }

      return target[key];
    },

    set() {
      throw new Error(`Read model sources are immutable`);
    }

  });
  Object.defineProperties(resolve, {
    readModelConnectors: {
      value: readModelConnectors
    },
    eventstoreAdapter: {
      value: eventstoreAdapter
    },
    readModelSources: {
      value: readModelSources
    }
  });
  const getVacantTimeInMillis = resolve.getVacantTimeInMillis;
  const notifyEventSubscribers = (0, _notifyEventSubscribers.default)(resolve);
  const onCommandExecuted = (0, _onCommandExecuted.default)(resolve);
  const secretsManager = await eventstoreAdapter.getSecretsManager();
  const {
    command: commandMiddlewares = [],
    resolver: resolverMiddlewares = [],
    projection: projectionMiddlewares = []
  } = (_domain$middlewares = domain.middlewares) !== null && _domain$middlewares !== void 0 ? _domain$middlewares : {};
  const aggregateRuntime = {
    monitoring,
    secretsManager,
    eventstore: eventstoreAdapter,
    hooks: {
      postSaveEvent: async (aggregate, command, event, eventWithCursor) => {
        await onCommandExecuted(event, command, eventWithCursor);
        return false;
      }
    },
    commandMiddlewares
  };
  const executeCommand = (0, _index.default)({
    performanceTracer,
    aggregatesInterop: domainInterop.aggregateDomain.acquireAggregatesInterop(aggregateRuntime)
  });
  const executeSchedulerCommand = (0, _index.default)({
    performanceTracer,
    aggregatesInterop: domainInterop.sagaDomain.acquireSchedulerAggregatesInterop(aggregateRuntime)
  });
  const executeQuery = (0, _index2.default)({
    invokeBuildAsync,
    applicationName: eventSubscriberScope,
    eventstoreAdapter,
    readModelConnectors,
    readModelSources,
    performanceTracer,
    getVacantTimeInMillis,
    monitoring,
    readModelsInterop: domainInterop.readModelDomain.acquireReadModelsInterop({
      monitoring,
      secretsManager,
      resolverMiddlewares,
      projectionMiddlewares
    }),
    viewModelsInterop: domainInterop.viewModelDomain.acquireViewModelsInterop({
      monitoring,
      eventstore: eventstoreAdapter,
      secretsManager
    })
  });
  const executeSaga = (0, _index3.default)({
    invokeBuildAsync,
    applicationName: eventSubscriberScope,
    executeCommand,
    executeQuery,
    eventstoreAdapter,
    secretsManager,
    readModelConnectors,
    performanceTracer,
    getVacantTimeInMillis,
    uploader,
    scheduler,
    monitoring,
    domainInterop,
    executeSchedulerCommand
  });
  const eventSubscriber = (0, _eventSubscriber.default)(resolve);
  Object.assign(resolve, {
    isInitialized: true,
    executeCommand,
    executeQuery,
    executeSaga,
    executeSchedulerCommand,
    notifyEventSubscribers
  });
  Object.defineProperties(resolve, {
    eventSubscriber: {
      value: eventSubscriber
    }
  });
  process.env.RESOLVE_LOCAL_TRACE_ID = _crypto.default.randomBytes(Math.ceil(32 / 2)).toString('hex').slice(0, 32);
};

var _default = initResolve;
exports.default = _default;
//# sourceMappingURL=init-resolve.js.map