"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const shutdownOne = async ({
  applicationName,
  name,
  eventstoreAdapter,
  eventSubscriber,
  upstream,
  deleteQueue,
  soft
}) => {
  try {
    const errors = [];

    try {
      if (upstream) {
        await eventSubscriber.pause({
          eventSubscriber: name
        });
      }

      if (!soft) {
        await eventSubscriber.unsubscribe({
          eventSubscriber: name
        });
      }
    } catch (err) {
      errors.push(err);
    }

    try {
      await eventstoreAdapter.removeEventSubscriber({
        applicationName,
        eventSubscriber: name
      });
    } catch (err) {
      errors.push(err);
    }

    try {
      await deleteQueue(name);
    } catch (err) {
      errors.push(err);
    }

    if (errors.length > 0) {
      const summaryError = new Error(errors.map(({
        message
      }) => message).join('\n'));
      summaryError.stack = errors.map(({
        stack
      }) => stack).join('\n');
      throw summaryError;
    }
  } catch (error) {
    // eslint-disable-next-line no-console
    console.warn(`
      Event subscriber "${name}" can't stop subscription due to error "${error}"
    `);
  }
};

var _default = shutdownOne;
exports.default = _default;
//# sourceMappingURL=shutdown-one.js.map