"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _routeTrie = _interopRequireDefault(require("route-trie"));

var _commandHandler = _interopRequireDefault(require("./handlers/command-handler"));

var _queryHandler = _interopRequireDefault(require("./handlers/query-handler"));

var _markupHandler = _interopRequireDefault(require("./handlers/markup-handler"));

var _uploaderHandler = _interopRequireDefault(require("./handlers/uploader-handler"));

var _failHandler = _interopRequireDefault(require("./handlers/fail-handler"));

var _getRootBasedUrl = _interopRequireDefault(require("./utils/get-root-based-url"));

var _builtinRoutes = _interopRequireDefault(require("./defaults/builtin-routes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const wrapTrie = (apiHandlers, staticRoutes, rootPath, customStaticHandler) => {
  const staticHandler = typeof customStaticHandler === 'function' ? customStaticHandler : _failHandler.default;
  const trie = new _routeTrie.default({
    ignoreCase: false,
    fixedPathRedirect: true,
    trailingSlashRedirect: true
  });

  for (const {
    method,
    path,
    handler
  } of _builtinRoutes.default) {
    trie.define((0, _getRootBasedUrl.default)(rootPath, path)).handle(method, handler === 'QUERY' ? _queryHandler.default : handler === 'COMMAND' ? _commandHandler.default : handler === 'UPLOADER' ? _uploaderHandler.default : _failHandler.default);
  }

  for (const {
    method,
    path,
    handler
  } of apiHandlers) {
    trie.define((0, _getRootBasedUrl.default)(rootPath, path)).handle(String(method).toUpperCase(), handler);
  }

  if (Array.isArray(staticRoutes)) {
    for (const [staticPath] of staticRoutes) {
      trie.define((0, _getRootBasedUrl.default)(rootPath, staticPath)).handle('GET', staticHandler);
      trie.define((0, _getRootBasedUrl.default)(rootPath, staticPath)).handle('HEAD', staticHandler);
    }
  }

  try {
    trie.define((0, _getRootBasedUrl.default)(rootPath, '/:markup*')).handle('GET', _markupHandler.default);
  } catch (e) {}

  return trie;
};

var _default = wrapTrie;
exports.default = _default;
//# sourceMappingURL=wrap-trie.js.map