"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("source-map-support/register");

var _debugLevels = _interopRequireDefault(require("@resolve-js/debug-levels"));

var _core = require("@resolve-js/core");

var _http = _interopRequireDefault(require("http"));

var _https = _interopRequireDefault(require("https"));

var _initPerformanceTracer = _interopRequireDefault(require("./init-performance-tracer"));

var _initExpress = _interopRequireDefault(require("./init-express"));

var _initWebsockets = _interopRequireDefault(require("./init-websockets"));

var _startExpress = _interopRequireDefault(require("./start-express"));

var _emptyWorker = _interopRequireDefault(require("./empty-worker"));

var _initUploader = _interopRequireDefault(require("./init-uploader"));

var _initScheduler = _interopRequireDefault(require("./init-scheduler"));

var _gatherEventListeners = _interopRequireDefault(require("../common/gather-event-listeners"));

var _initResolve = _interopRequireDefault(require("../common/init-resolve"));

var _disposeResolve = _interopRequireDefault(require("../common/dispose-resolve"));

var _multiplexAsync = _interopRequireDefault(require("../common/utils/multiplex-async"));

var _getRootBasedUrl = _interopRequireDefault(require("../common/utils/get-root-based-url"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _debugLevels.default)('resolve:runtime:local-entry');

const localEntry = async ({
  assemblies,
  constants,
  domain
}) => {
  try {
    var _resolve$host;

    domain.apiHandlers.push({
      path: '/api/subscribers/:eventSubscriber',
      method: 'GET',
      handler: async (req, res) => {
        try {
          const baseQueryUrl = (0, _getRootBasedUrl.default)(req.resolve.rootPath, '/api/subscribers/');
          const eventSubscriber = req.path.substring(baseQueryUrl.length);
          await req.resolve.eventSubscriber.build({
            eventSubscriber
          });
          await res.end('ok');
        } catch (error) {
          // eslint-disable-next-line no-console
          console.error(error);
          await res.end(error);
        }
      }
    });
    const domainInterop = await (0, _core.initDomain)(domain);
    const resolve = {
      instanceId: `${process.pid}${Math.floor(Math.random() * 100000)}`,
      seedClientEnvs: assemblies.seedClientEnvs,
      serverImports: assemblies.serverImports,
      domain,
      ...constants,
      assemblies,
      domainInterop,
      eventListeners: (0, _gatherEventListeners.default)(domain, domainInterop),
      eventSubscriberScope: constants.applicationName,
      upstream: domain.apiHandlers.findIndex(({
        method,
        path
      }) => method === 'OPTIONS' && path === '/SKIP_COMMANDS') < 0,
      https: _https.default,
      http: _http.default
    };
    resolve.host = (_resolve$host = resolve.host) !== null && _resolve$host !== void 0 ? _resolve$host : '0.0.0.0';

    resolve.getEventSubscriberDestination = () => `http://${resolve.host}:${resolve.port}/api/subscribers`;

    resolve.invokeBuildAsync = _multiplexAsync.default.bind(null, async parameters => {
      const currentResolve = Object.create(resolve);

      try {
        await (0, _initResolve.default)(currentResolve);
        const result = await currentResolve.eventSubscriber.build(parameters);
        return result;
      } finally {
        await (0, _disposeResolve.default)(currentResolve);
      }
    });

    resolve.ensureQueue = async () => {};

    resolve.deleteQueue = async () => {};

    await (0, _initPerformanceTracer.default)(resolve);
    await (0, _initExpress.default)(resolve);
    await (0, _initWebsockets.default)(resolve);
    await (0, _initUploader.default)(resolve);
    await (0, _initScheduler.default)(resolve);
    await (0, _startExpress.default)(resolve);
    log.debug('Local entry point cold start success');
    return _emptyWorker.default;
  } catch (error) {
    log.error('Local entry point cold start failure', error);
  }
};

var _default = localEntry;
exports.default = _default;
//# sourceMappingURL=index.js.map