"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _express = _interopRequireDefault(require("express"));

var _http = require("http");

var _path = _interopRequireDefault(require("path"));

var _wrapApiHandler = _interopRequireDefault(require("./wrap-api-handler"));

var _mainHandler = _interopRequireDefault(require("../common/handlers/main-handler"));

var _getRootBasedUrl = _interopRequireDefault(require("../common/utils/get-root-based-url"));

var _wrapTrie = _interopRequireDefault(require("../common/wrap-trie"));

var _initResolve = _interopRequireDefault(require("../common/init-resolve"));

var _disposeResolve = _interopRequireDefault(require("../common/dispose-resolve"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const staticRouteMarkerHandler = () => {};

const initExpress = async resolve => {
  const app = (0, _express.default)();
  const server = new _http.Server(app);
  Object.defineProperties(resolve, {
    routesTrie: {
      value: (0, _wrapTrie.default)(resolve.domain.apiHandlers, resolve.staticRoutes, resolve.rootPath, staticRouteMarkerHandler),
      enumerable: true
    },
    app: {
      value: app
    },
    server: {
      value: server
    }
  });

  if (resolve.staticPath != null && resolve.staticRoutes != null) {
    throw new Error(`Static routing failed`);
  }

  const expressStaticMiddleware = _express.default.static(_path.default.join(process.cwd(), resolve.distDir, './client'));

  if (resolve.staticPath != null) {
    resolve.app.use((0, _getRootBasedUrl.default)(resolve.rootPath, `/${resolve.staticPath}`), expressStaticMiddleware);
  }

  resolve.app.use(async (req, res, next) => {
    if (resolve.staticRoutes != null) {
      var _resolve$routesTrie$m;

      const {
        node
      } = (_resolve$routesTrie$m = resolve.routesTrie.match(req.path)) !== null && _resolve$routesTrie$m !== void 0 ? _resolve$routesTrie$m : {
        node: null
      };

      if (node != null) {
        var _resolve$staticRoutes;

        const handler = node.getHandler(req.method.toUpperCase());
        const maybeMappedStaticFile = ((_resolve$staticRoutes = resolve.staticRoutes.find(route => route[0] === node.pattern)) !== null && _resolve$staticRoutes !== void 0 ? _resolve$staticRoutes : [])[1];

        if (handler === staticRouteMarkerHandler) {
          return await expressStaticMiddleware(maybeMappedStaticFile != null ? Object.create(req, {
            originalUrl: {
              value: `/${maybeMappedStaticFile}`,
              enumerable: true
            },
            url: {
              value: `/${maybeMappedStaticFile}`,
              enumerable: true
            },
            path: {
              value: `/${maybeMappedStaticFile}`,
              enumerable: true
            },
            params: {
              value: {},
              enumerable: true
            },
            query: {
              value: {},
              enumerable: true
            }
          }) : req, res, next);
        }
      }
    }

    const currentResolve = Object.create(resolve);

    try {
      await (0, _initResolve.default)(currentResolve);

      const getCustomParameters = async () => ({
        resolve: currentResolve
      });

      const executor = (0, _wrapApiHandler.default)(_mainHandler.default, getCustomParameters);
      await executor(req, res);
    } finally {
      await (0, _disposeResolve.default)(currentResolve);
    }
  });
};

var _default = initExpress;
exports.default = _default;
//# sourceMappingURL=init-express.js.map